=============================
Sky matching for image mosaic
=============================

.. moduleauthor:: Mihai Cara, Pey Lian Lim, Warren Hack

.. currentmodule:: stsci.skypac.skymatch

.. automodule:: stsci.skypac.skymatch
   :members:
..   :undoc-members:
